summaryrefslogtreecommitdiffstats
path: root/apps/files/js/filelist.js
diff options
context:
space:
mode:
Diffstat (limited to 'apps/files/js/filelist.js')
-rw-r--r--apps/files/js/filelist.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/apps/files/js/filelist.js b/apps/files/js/filelist.js
index 4d3a171a8e7..22b5a82326a 100644
--- a/apps/files/js/filelist.js
+++ b/apps/files/js/filelist.js
@@ -3523,9 +3523,9 @@
var _this = this;
var $scrollContainer = this.$container;
if ($scrollContainer[0] === window) {
// need to use "body" to animate scrolling
// when the scroll container is the window
- $scrollContainer = $('body');
+ $scrollContainer = $('html');
}
$scrollContainer.animate({
// Scrolling to the top of the new element
@@ -3523,9 +3523,9 @@
var $scrollContainer = this.$container;
if ($scrollContainer[0] === window) {
- // need to use "body" to animate scrolling
+ // need to use "html" to animate scrolling
// when the scroll container is the window